mod lib_test;

use serde::Deserialize;
use trust_dns_resolver::AsyncResolver;
use reqwest;

#[derive(Deserialize)]
pub struct TokenServiceApi {
  pub main:         String,
  pub octokit:      String,
  pub youtube:      String,
  pub postgres_uri: String,
  pub redis_uri:    String,
  pub wg_pms:       String
}

pub struct TokenService {
  endpoint: String,
  server: String
}

impl TokenService {
  pub fn new(endpoint: &str/*, protocol: bool*/) -> Self {
    TokenService {
      endpoint: endpoint.to_string(),
      server: "ts.local.toast-data.center".to_string()
    }
  }

  pub async fn connect(&self) -> Result<TokenServiceApi, Box<dyn std::error::Error + Send + Sync>> {
    let resolver = AsyncResolver::tokio_from_system_conf();

    let _  = resolver;
    let url = format!("http://{}/{}", self.server, self.endpoint);
    let response = reqwest::get(&url).await?;
    let api: TokenServiceApi = response.json().await?;

    Ok(api)
  }
}
